koa-better-ratelimit [![Build Status](https://travis-ci.org/tunnckoCore/koa-better-ratelimit.png)](https://travis-ci.org/tunnckoCore/koa-better-ratelimit) [![Dependencies Status](https://david-dm.org/tunnckoCore/koa-better-ratelimit/status.svg)](https://david-dm.org/tunnckoCore/koa-better-ratelimit)
================

> Better, smaller, faster. KoaJS middleware for limit request by ip, store in-memory.

## Install
> Install [`package/koa-better-ratelimit`](http://npm.im/koa-better-ratelimit) with [npm](https://npmjs.org)

```
$ npm install koa-better-ratelimit
```

## Options
> With options through init you can control black/white lists, limit per ip and reset interval.

- `duration` **{Integer}** Limit duration in seconds, default `1000 * 60 * 60 * 1` (1 hour)
- `whiteList` **{Array}** All ips that won't be limited, default `empty array`
- `blackList` **{Array}** All ips that always be limited and 403, default `empty array`
- `message_429` **{String}** Message for all requests after limit, default `429: Too Many Requests.`
- `message_403` **{String}** Message for limited/forbidden 403, default `403: This is forbidden area for you.`
- `max` **{Integer}** Max requests per ip, default `500`
- `env` **{Boolean}** Manage enviroment, for tests will use `x-koaip` header, default `null`


## Usage
> Some demo example which is exactly `example.js`

```js
var app   = require('koa')(),
    limit = require('./index');

app.use(limit({
  duration: 1000 * 60 * 3, //3 mins
  max: 5,
  //blackList: ['127.0.0.1']
}));

app.use(function * (next) {
  this.body = 'Hello World';
  yield next;
});

var port = process.env.PORT || 3333;
app.listen(3333);
console.log('Koa server start listening on port ' + port);
```

## Diferences
> Between [koa-better-ratelimit](https://github.com/tunnckoCore/koa-better-ratelimit) and [koa-ratelimit](https://github.com/koajs/ratelimit)

- Support blackList and whiteList options
- Pure in-memory store, no other adapters
- `duration` option in seconds, not in milliseconds
- 7 working tests
- removed `db` option
- added `Retry-After` header
- added separate 403 and 429 option messages

> Between [koa-better-ratelimit](https://github.com/tunnckoCore/koa-better-ratelimit) and [koa-limit](https://github.com/koajs/koa-limit)

- koa-limit [is totally broken](https://github.com/koajs/koa-limit/issues/3#issuecomment-42731409) (to v1.0.1)
- removed `redis` and test dependencies
- smaller, better, working, simple
- added separate 403 and 429 option messages


## Test, Bench, Example
> First run `npm install`

```
$ npm test
$ npm start
```


## License
The MIT License, 2014 [Charlike Mike Reagent](https://github.com/tunnckoCore) ([@tunnckoCore](https://twitter.com/tunnckoCore))
***
_This file was generated by [`Ock`](https://github.com/tosckjs/ock) on June 20, 2014._
